@import url("cubicweb.css");

/* template specific CSS */

table{
 border-collapse:collapse;
 border: none;
 }

/* calendars */

#activities_box .boxContent{
 padding:1px 1px 0px;
}

#activities_box .boxTitle{
 background: #CFCEB7;
 color : #000;
 text-align: center;
}

table.userCal,
table.activitiesCal{
 text-align: center;
 border-collapse:collapse;
 width:100%;
}

table.userCal th,
table.activitiesCal th{
 background:#CFCEB7;
 border: 1px solid #C1C1C1;
 color: #000;
}

table.userCal th.calTitle,
table.userCal th.prev,
table.userCal th.next,
table.activitiesCal th.calTitle,
table.activitiesCal th.prev,
table.activitiesCal th.next{
 padding: 0px;
}

table.userCal th.prev,
table.userCal th.next,
table.activitiesCal th.prev,
table.activitiesCal th.next{
  font-size: 50%;
  font-weight: bold;
  padding: 2px 0px;
}

table.activitiesCal td {
 width: 2em;
 height: 2em;
 border:1px solid #C1C1C1;
 font-size: 85%;
}

table.activitiesCal td.today{
 border: 1px solid #000;
 font-weight:bold;
 }

table.activitiesCal td.today a{
 color:#000;
 }
table.activitiesCal td.problem,
table.activitiesCal td.problem a{
 color: #d50a2a;
}

table.activitiesCal td.pending a{
 color: #ff9900;
 }

table.activitiesCal td.completed a{
 color : #539d02;
 }


table.activitiesCal td.timeframe {
  background: #d5d5bd;
  font-weight: bold;
  color: white;
}

table.activitiesCal td.holidays,
table.activitiesCal td.closed {
  font-weight: normal;
  background : #f6f5e1;
  color: #888;
}

table.activitiesCal td.daytype_pending {
  font-weight: normal;
  background : #e0e0ff;
  color: #888;
}

table.activitiesCal td.unknown {
    color: #d50a2a;
    text-decoration: line-through;
}

table.activitiesCal td.holidays a{
 color:#888;
 }

table div.subinvoiced {
  color: red;
  font-weight: bold;
}

table div.overinvoiced {
  color: green;
  font-weight: bold;
}


/* user calendar */

table.caldata{
 border-collapse:collapse;
 height:100%;
 width:100%;
}

table.userCal td{
 border:1px solid #C1C1C1;
 padding:0px 2px 2px;
 height:100%;
}

table.caldata td{
 font-size: 85%;
 border:none;
 padding:0px;
 margin:0px;
 vertical-align:top;
}

table.caldata td a{
 color:#000;
 }

table.caldata td.caldate{
 text-align:left;
 font-weight:bold;
 height:1.6em;
 }

table.caldata td.am,
table.caldata td.pm{
 text-align:right;
 border-top:1px dotted #C1C1C1;
 height:40% !important;
}

table.userCal td.working  div.caldate a,
table.userCal td.working_pm  div.caldate a,
table.userCal td.working_am  div.caldate a{
 color: #000;
}

table.caldata td.caldate a{
font-size:120%;
 padding-bottom:0.2em;
}

table.caldata td.am,
table.caldata td.pm{
 font-size:95%;
}

table.userCal td.week{
 width:10%;
 background:#f6f5e1 ;
 font-size: 85%;
 }

table.userCal td.working td.pm,
table.userCal td.working td.am,
table.userCal td.working_pm td.pm,
table.userCal td.working_am td.am{
 background:#fff;
 color: #888;
}

table.userCal td.non_working td.pm,
table.userCal td.non_working td.am{
 background:#f6f5e1 ;
 color: #888;
}

table.userCal td.non_working_pending td.pm,
table.userCal td.non_working_pending td.am{
 background: #e0e0ff;
 color: #888;
}

table.userCal td.working_pm td.am,
table.userCal td.working_am td.pm{
 background:#f6f5e1 ;
 color: #ff4500;
}

table.userCal td.working_pm_pending td.am,
table.userCal td.working_am_pending td.pm{
 background: #e0e0ff;
 color: #ff4500;
}

table.userCal td.today td.caldate a {
 font-weight:bold;
 color: #539d02;
}

table.caldata div.stickers{
 color:#000;
 padding: 0pt 0.2em 0.2em  0.8em;
}

table.caldata .mday{
 text-align: left;
}


.cal_properties a{
 display:block;
 margin: 10px 0px 6px 0px;
 font-weight: bold;
 color: #000;
 padding: 0.2em 0.2em 0.2em 16px;
 background:#eeedd9 url("puce_down.png") 3px center no-repeat;
 font-size:76%;
 }

/* cubicweb overwriten styles */
